/* GMM (C) 2018 Stephane Charette <stephanecharette@gmail.com>
 * $Id: GMMTypes.hpp 2640 2018-10-18 08:35:21Z stephane $
 */

#pragma once

#include <algorithm>
#include <chrono>
#include <iomanip>
#include <fstream>
#include <sstream>
#include <memory>
#include <string>
#include <thread>
#include <regex>
#include <map>
#include <cmath>
#include <set>
#include <list>
#include <vector>
#include <iomanip>
#include <fstream>

#include <ciso646>
#include <cstdlib>
#include <ctime>

#include "JuceHeader.h"

#include <Loxahatchee/Loxahatchee.hpp>

#ifdef WIN32
#include <windows.h>
#else
// couple of Windows things needed to get everything building on Linux
typedef int HANDLE;
#define INVALID_HANDLE_VALUE 0
#endif

typedef std::set	<std::string>	SStr;
typedef std::vector	<std::string>	VStr;
typedef std::vector	<uint8_t>		VBytes;
typedef std::list	<double>		LDouble;
